use crate::{
	app::Message,
	calendar::CalendarViewMode as ViewMode
};
use chrono::{NaiveDate, Datelike};
use iced::{
    alignment,
    Alignment,
    Element,
    Length,
    widget::{
		button,
		Row,
	    Button,
	    Text,
	    pick_list,
	},
};

//#[derive(Default)]
pub struct Controls {
    pub mode: Option<ViewMode>,
}

impl Default for Controls {
    fn default() -> Controls {
        Controls {
            mode : Some(ViewMode::Year)
        }
    }
}

impl Controls {
    const MODES : [ViewMode; 3] = [ViewMode::Week, ViewMode::Month, ViewMode::Year];
    const MONTH_NAMES: [&'static str;12] = [
        "gennaio",
        "febbraio",
        "marzo",
        "aprile",
        "maggio",
        "giugno",
        "luglio",
        "agosto",
        "settembre",
        "ottobre",
        "novembre",
        "dicembre",
    ];

    pub fn view<'a>(&'a self, view_date: NaiveDate, year: i32) -> Element<Message> {
        let description = match self.mode {
            Some(ViewMode::Month) => Controls::MONTH_NAMES[view_date.month0() as usize],
            _ => ""
        };
        Row::new()
            .align_items(Alignment::Center)
            .padding(5)
            .spacing(10)
            .push(
                pick_list(
                &Controls::MODES[..],
                self.mode,
                Message::ViewModeSelected,
                ).placeholder("mode")
            )
            .push(
                Button::new(Text::new("<"))
                .on_press(self.get_msg_prev())
                .style(button::secondary),
            )
            .push(
                Button::new(Text::new(">"))
                    .on_press(self.get_msg_next())
                    .style(button::secondary),
            )
            .push(
                Text::new(description)
                    .width(Length::Fill)
                    .horizontal_alignment(alignment::Horizontal::Left)
                    .size(40),
            )
            .push(
                Text::new(year.to_string())
                    .width(Length::Fill)
                    .horizontal_alignment(alignment::Horizontal::Right)
                    .size(40),
            )
            .into()
    }

    fn get_msg_next(&self) -> Message {
        match self.mode {
            Some(ViewMode::Week) => Message::NextWeek,
            Some(ViewMode::Month) => Message::NextMonth,
            Some(ViewMode::Year) => Message::NextYear,
            None => todo!(),
        }
    }

    fn get_msg_prev(&self) -> Message {
        match self.mode {
            Some(ViewMode::Week) => Message::PrevWeek,
            Some(ViewMode::Month) => Message::PrevMonth,
            Some(ViewMode::Year) => Message::PrevYear,
            None => todo!(),
        }
    }
}
